@@ -466,6 +466,61 @@ describe('maps with no values', () => {
   })
 })
 
+describe('collection item with anchor followed by empty line (#242)', () => {
+  test('reported 1', () => {
+    const src = `
+key1: &default
+
+  subkey1: value1
+
+key2:
+  <<: *default\n`
+    expect(YAML.parse(src, { merge: true })).toMatchObject({
+      key1: { subkey1: 'value1' },
+      key2: { subkey1: 'value1' }
+    })
+  })
+
+  test('reported 2', () => {
+    const src = `
+key1: &default
+
+  # This key ...
+  subkey1: value1
+
+key2:
+  <<: *default\n`
+    expect(YAML.parse(src, { merge: true })).toMatchObject({
+      key1: { subkey1: 'value1' },
+      key2: { subkey1: 'value1' }
+    })
+  })
+
+  test('reported 3', () => {
+    const src = `
+key1: &default
+# This key ...
+  subkey1: value1
+
+key2:
+  <<: *default\n`
+    expect(YAML.parse(src, { merge: true })).toMatchObject({
+      key1: { subkey1: 'value1' },
+      key2: { subkey1: 'value1' }
+    })
+  })
+
+  test('minimal with anchor', () => {
+    const src = '- &a\n\n  foo'
+    expect(YAML.parse(src)).toMatchObject(['foo'])
+  })
+
+  test('minimal with tag', () => {
+    const src = '- !!str\n\n  foo'
+    expect(YAML.parse(src)).toMatchObject(['foo'])
+  })
+})
+
 describe('Excessive entity expansion attacks', () => {
   const root = path.resolve(__dirname, '../artifacts/pr104')
   const src1 = fs.readFileSync(path.resolve(root, 'case1.yml'), 'utf8')
@@ -612,3 +667,22 @@ test('Document.toJSON(null, onAnchor)', () => {
     ['foo', 1]
   ])
 })
+
+describe('__proto__ as mapping key', () => {
+  test('plain object', () => {
+    const src = '{ __proto__: [42] }'
+    const obj = YAML.parse(src)
+    expect(Array.isArray(obj)).toBe(false)
+    expect(obj.hasOwnProperty('__proto__')).toBe(true)
+    expect(obj).not.toHaveProperty('length')
+    expect(JSON.stringify(obj)).toBe('{"__proto__":[42]}')
+  })
+
+  test('with merge key', () => {
+    const src = '- &A { __proto__: [42] }\n- { <<: *A }\n'
+    const obj = YAML.parse(src, { merge: true })
+    expect(obj[0].hasOwnProperty('__proto__')).toBe(true)
+    expect(obj[1].hasOwnProperty('__proto__')).toBe(true)
+    expect(JSON.stringify(obj)).toBe('[{"__proto__":[42]},{"__proto__":[42]}]')
+  })
+})
