@@ -311,6 +311,15 @@ z:
     const doc = YAML.parseDocument('? >+ #comment\n foo\n\n: bar')
     expect(String(doc)).toBe('? >+ #comment\n  foo\n\n: bar\n')
   })
+
+  test('Document as key', () => {
+    const doc1 = new YAML.Document()
+    doc1.contents = YAML.createNode({ a: 1 })
+    const doc2 = new YAML.Document()
+    doc2.contents = YAML.createNode({ b: 2, c: 3 })
+    doc1.add(doc2)
+    expect(String(doc1)).toBe('a: 1\n? b: 2\n  c: 3\n: null\n')
+  })
 })
 
 test('eemeli/yaml#43: Quoting colons', () => {
@@ -469,6 +478,18 @@ describe('simple keys', () => {
       /With simple keys, collection cannot be used as a key value/
     )
   })
+
+  test('key value lingth > 1024', () => {
+    let str = `
+    ? ${new Array(1026).join('a')}
+    : longkey`
+    const doc = YAML.parseDocument(str)
+    expect(String(doc)).toBe(`? ${new Array(1026).join('a')}\n: longkey\n`)
+    doc.options.simpleKeys = true
+    expect(() => String(doc)).toThrow(
+      /With simple keys, single line scalar must not span more than 1024 characters/
+    )
+  })
 })
 
 test('eemeli/yaml#128: YAML node inside object', () => {
@@ -677,3 +698,10 @@ describe('Document markers in top-level scalars', () => {
     expect(YAML.parse(str)).toBe('foo\n%bar\n')
   })
 })
+
+describe('YAML.stringify on ast Document', () => {
+  test('null document', () => {
+    const doc = YAML.parseDocument('null')
+    expect(YAML.stringify(doc)).toBe('null\n')
+  })
+})
